@@ -1,3 +1,5 @@
 from cgdb.cgdb import CGDB
 from cgdb import exceptions
-from cgdb import recources
\ No newline at end of file
+from cgdb import recources
+from cgdb import managers
+from cgdb import utils
